function sqr = JSW_SquareWaveShock(PulseWidth,PulseGap,amplitude,nreps);
%
%  sqr = JSW_SquareWaveShock(PulseWidth,PulseGap,amplitude,nreps);
% 
% A function to deliver a repeating square wave stimulus via the analogue
% output on the NI-DAQ.
%
% Can specify pulse width (microseconds), number of repetitions, size of
% gaps (microseconds) and amplitude (V).  Time-based measurements will be
% rounded to the nearest 10 (maximum sample rate for output is 100KS/s, 
% i.e. 10microseconds resolution).
%
% defaults: PulseWidth = 1000;
%           PulseGap   = 49000; (one pulse/50ms)
%           amplitude  = 1;
%           nreps      = 10;
%
% Output "sqr" is square wave function delivered to NI-DAQ.
%
% It seems to hurt more with settings: 
%   sqr = SquareWaveShock(10000,49000,1,10);
% (i.e. longer pulse width)
%
% ======================================================================
% JSW 9/7/10, edited Feb 2013 to convert to us timebase
% ======================================================================
%

global ao

if(nargin<4)
    nreps = 10;
end
if(nargin<3)
    amplitude = 1;
end
if(nargin<2)
    PulseGap = 49000;
end
if(nargin<1)
    PulseWidth = 1000;
end

fs = ao.SampleRate;
scalesamplingrate = 10^6/fs;

% Convert times to sampling space (divide by scaling factor for sampling rate and round, basically)    
PulseWidth = round(PulseWidth/scalesamplingrate);
PulseGap   = round(PulseGap/scalesamplingrate);

% Construct single pulse
LenSinglePulse   = (PulseWidth + PulseGap);
sq               = zeros(LenSinglePulse,1);
onset            = 1;
offset           = PulseWidth;
sq(onset:offset) = amplitude;

% Construct pulse train
sqr = repmat(sq,nreps,1);

% Deliver pulses
if (strmatch('On',get(ao,'Running')));  % Need to stop ao object if currently running (e.g. with excitation for GSR)
    stop(ao);          % Stop current output
    putsample(ao,0);  % Empty analogue output buffer
end
try
    putdata(ao,sqr);  % Load pulse train
    start(ao);         % Start analogue output object
    wait(ao,5)  ;      % Wait for analogue output to stop (or 5s, whichever is sooner)
catch
    disp('Could not communicate with DAQ - no pulses delivered...')
    return
end
